@@ -333,7 +333,7 @@ _gnutls_selected_cert_supported_kx (gnutls_session_t session,
       return GNUTLS_E_INVALID_REQUEST;
     }
 
-  *alg = gnutls_calloc (1, sizeof (gnutls_kx_algorithm_t) * i);
+  *alg = gnutls_calloc (i, sizeof (gnutls_kx_algorithm_t));
   if (*alg == NULL)
     return GNUTLS_E_MEMORY_ERROR;
 
@@ -757,8 +757,9 @@ _gnutls_get_auth_info_gcert (gnutls_cert * gcert,
     case GNUTLS_CRT_OPENPGP:
       return _gnutls_openpgp_raw_crt_to_gcert (gcert,
 					       &info->raw_certificate_list[0],
-					       info->use_subkey ? info->
-					       subkey_id : NULL);
+					       info->
+					       use_subkey ? info->subkey_id :
+					       NULL);
 #endif
     default:
       gnutls_assert ();
