@@ -89,19 +89,6 @@ _gnutls_m_compressed2plaintext (gnutls_session_t session,
 #define MAX_COMP_METHODS 5
 const int _gnutls_comp_algorithms_size = MAX_COMP_METHODS;
 
-struct gnutls_compression_entry
-{
-  const char *name;
-  gnutls_compression_method_t id;
-  int num;			/* the number reserved in TLS for the specific compression method */
-
-  /* used in zlib compressor */
-  int window_bits;
-  int mem_level;
-  int comp_level;
-};
-typedef struct gnutls_compression_entry gnutls_compression_entry;
-
 gnutls_compression_entry _gnutls_compression_algorithms[MAX_COMP_METHODS] = {
   GNUTLS_COMPRESSION_ENTRY (GNUTLS_COMP_NULL, 0x00, 0, 0, 0),
 #ifdef HAVE_LIBZ
@@ -167,9 +154,9 @@ gnutls_compression_get_id (const char *name)
   gnutls_compression_method_t ret = GNUTLS_COMP_UNKNOWN;
 
   GNUTLS_COMPRESSION_LOOP (if
-      (strcasecmp
-       (p->name + sizeof ("GNUTLS_COMP_") - 1,
-	name) == 0) ret = p->id);
+			   (strcasecmp
+			    (p->name + sizeof ("GNUTLS_COMP_") - 1,
+			     name) == 0) ret = p->id);
 
   return ret;
 }
@@ -277,8 +264,8 @@ _gnutls_supported_compression_methods (gnutls_session_t session,
   for (i = j = 0; i < SUPPORTED_COMPRESSION_METHODS; i++)
     {
       int tmp =
-	_gnutls_compression_get_num (session->internals.
-				     priorities.compression.priority[i]);
+	_gnutls_compression_get_num (session->internals.priorities.
+				     compression.priority[i]);
 
       /* remove private compression algorithms, if requested.
        */
