@@ -132,8 +132,7 @@ _gnutls_x509_cert_verify_peers (gnutls_session_t session,
    */
   peer_certificate_list_size = info->ncerts;
   peer_certificate_list =
-    gnutls_calloc (1,
-		   peer_certificate_list_size * sizeof (gnutls_x509_crt_t));
+    gnutls_calloc (peer_certificate_list_size, sizeof (gnutls_x509_crt_t));
   if (peer_certificate_list == NULL)
     {
       gnutls_assert ();
@@ -218,8 +217,8 @@ _gnutls_check_key_cert_match (gnutls_certificate_credentials_t res)
 					       1].params_size, &kid);
 
 
-      _gnutls_x509_write_rsa_params (res->
-				     cert_list[res->ncerts - 1][0].params,
+      _gnutls_x509_write_rsa_params (res->cert_list[res->ncerts - 1][0].
+				     params,
 				     res->cert_list[res->ncerts -
 						    1][0].params_size, &cid);
     }
@@ -230,8 +229,8 @@ _gnutls_check_key_cert_match (gnutls_certificate_credentials_t res)
 				     res->pkey[res->ncerts -
 					       1].params_size, &kid);
 
-      _gnutls_x509_write_dsa_params (res->
-				     cert_list[res->ncerts - 1][0].params,
+      _gnutls_x509_write_dsa_params (res->cert_list[res->ncerts - 1][0].
+				     params,
 				     res->cert_list[res->ncerts -
 						    1][0].params_size, &cid);
     }
