@@ -51,69 +51,69 @@
 
 static u32 crc_table[] = {
   0x000000, 0x864CFB, 0x8AD50D, 0x0C99F6, 0x93E6E1, 0x15AA1A, 0x1933EC,
-    0x9F7F17,
+  0x9F7F17,
   0xA18139, 0x27CDC2, 0x2B5434, 0xAD18CF, 0x3267D8, 0xB42B23, 0xB8B2D5,
-    0x3EFE2E,
+  0x3EFE2E,
   0xC54E89, 0x430272, 0x4F9B84, 0xC9D77F, 0x56A868, 0xD0E493, 0xDC7D65,
-    0x5A319E,
+  0x5A319E,
   0x64CFB0, 0xE2834B, 0xEE1ABD, 0x685646, 0xF72951, 0x7165AA, 0x7DFC5C,
-    0xFBB0A7,
+  0xFBB0A7,
   0x0CD1E9, 0x8A9D12, 0x8604E4, 0x00481F, 0x9F3708, 0x197BF3, 0x15E205,
-    0x93AEFE,
+  0x93AEFE,
   0xAD50D0, 0x2B1C2B, 0x2785DD, 0xA1C926, 0x3EB631, 0xB8FACA, 0xB4633C,
-    0x322FC7,
+  0x322FC7,
   0xC99F60, 0x4FD39B, 0x434A6D, 0xC50696, 0x5A7981, 0xDC357A, 0xD0AC8C,
-    0x56E077,
+  0x56E077,
   0x681E59, 0xEE52A2, 0xE2CB54, 0x6487AF, 0xFBF8B8, 0x7DB443, 0x712DB5,
-    0xF7614E,
+  0xF7614E,
   0x19A3D2, 0x9FEF29, 0x9376DF, 0x153A24, 0x8A4533, 0x0C09C8, 0x00903E,
-    0x86DCC5,
+  0x86DCC5,
   0xB822EB, 0x3E6E10, 0x32F7E6, 0xB4BB1D, 0x2BC40A, 0xAD88F1, 0xA11107,
-    0x275DFC,
+  0x275DFC,
   0xDCED5B, 0x5AA1A0, 0x563856, 0xD074AD, 0x4F0BBA, 0xC94741, 0xC5DEB7,
-    0x43924C,
+  0x43924C,
   0x7D6C62, 0xFB2099, 0xF7B96F, 0x71F594, 0xEE8A83, 0x68C678, 0x645F8E,
-    0xE21375,
+  0xE21375,
   0x15723B, 0x933EC0, 0x9FA736, 0x19EBCD, 0x8694DA, 0x00D821, 0x0C41D7,
-    0x8A0D2C,
+  0x8A0D2C,
   0xB4F302, 0x32BFF9, 0x3E260F, 0xB86AF4, 0x2715E3, 0xA15918, 0xADC0EE,
-    0x2B8C15,
+  0x2B8C15,
   0xD03CB2, 0x567049, 0x5AE9BF, 0xDCA544, 0x43DA53, 0xC596A8, 0xC90F5E,
-    0x4F43A5,
+  0x4F43A5,
   0x71BD8B, 0xF7F170, 0xFB6886, 0x7D247D, 0xE25B6A, 0x641791, 0x688E67,
-    0xEEC29C,
+  0xEEC29C,
   0x3347A4, 0xB50B5F, 0xB992A9, 0x3FDE52, 0xA0A145, 0x26EDBE, 0x2A7448,
-    0xAC38B3,
+  0xAC38B3,
   0x92C69D, 0x148A66, 0x181390, 0x9E5F6B, 0x01207C, 0x876C87, 0x8BF571,
-    0x0DB98A,
+  0x0DB98A,
   0xF6092D, 0x7045D6, 0x7CDC20, 0xFA90DB, 0x65EFCC, 0xE3A337, 0xEF3AC1,
-    0x69763A,
+  0x69763A,
   0x578814, 0xD1C4EF, 0xDD5D19, 0x5B11E2, 0xC46EF5, 0x42220E, 0x4EBBF8,
-    0xC8F703,
+  0xC8F703,
   0x3F964D, 0xB9DAB6, 0xB54340, 0x330FBB, 0xAC70AC, 0x2A3C57, 0x26A5A1,
-    0xA0E95A,
+  0xA0E95A,
   0x9E1774, 0x185B8F, 0x14C279, 0x928E82, 0x0DF195, 0x8BBD6E, 0x872498,
-    0x016863,
+  0x016863,
   0xFAD8C4, 0x7C943F, 0x700DC9, 0xF64132, 0x693E25, 0xEF72DE, 0xE3EB28,
-    0x65A7D3,
+  0x65A7D3,
   0x5B59FD, 0xDD1506, 0xD18CF0, 0x57C00B, 0xC8BF1C, 0x4EF3E7, 0x426A11,
-    0xC426EA,
+  0xC426EA,
   0x2AE476, 0xACA88D, 0xA0317B, 0x267D80, 0xB90297, 0x3F4E6C, 0x33D79A,
-    0xB59B61,
+  0xB59B61,
   0x8B654F, 0x0D29B4, 0x01B042, 0x87FCB9, 0x1883AE, 0x9ECF55, 0x9256A3,
-    0x141A58,
+  0x141A58,
   0xEFAAFF, 0x69E604, 0x657FF2, 0xE33309, 0x7C4C1E, 0xFA00E5, 0xF69913,
-    0x70D5E8,
+  0x70D5E8,
   0x4E2BC6, 0xC8673D, 0xC4FECB, 0x42B230, 0xDDCD27, 0x5B81DC, 0x57182A,
-    0xD154D1,
+  0xD154D1,
   0x26359F, 0xA07964, 0xACE092, 0x2AAC69, 0xB5D37E, 0x339F85, 0x3F0673,
-    0xB94A88,
+  0xB94A88,
   0x87B4A6, 0x01F85D, 0x0D61AB, 0x8B2D50, 0x145247, 0x921EBC, 0x9E874A,
-    0x18CBB1,
+  0x18CBB1,
   0xE37B16, 0x6537ED, 0x69AE1B, 0xEFE2E0, 0x709DF7, 0xF6D10C, 0xFA48FA,
-    0x7C0401,
+  0x7C0401,
   0x42FA2F, 0xC4B6D4, 0xC82F22, 0x4E63D9, 0xD11CCE, 0x575035, 0x5BC9C3,
-    0xDD8538
+  0xDD8538
 };
 
 static const char *armor_begin[] = {
@@ -161,7 +161,10 @@ static int
 base64_encode (char *out, const byte * in, size_t len, size_t olen)
 {
   if (!out || !in)
-    return CDK_Inv_Value;
+    {
+      gnutls_assert();
+      return CDK_Inv_Value;
+    }
 
   while (len >= 3 && olen > 10)
     {
@@ -200,23 +203,38 @@ base64_decode (byte * out, const char *in)
   byte digit1, digit2, digit3, digit4;
 
   if (!out || !in)
-    return -1;
+    {
+      gnutls_assert();
+      return -1;
+    }
 
   len = 0;
   do
     {
       digit1 = in[0];
       if (digit1 > 127 || b64val (digit1) == BAD)
-	return -1;
+        {
+          gnutls_assert();
+  	  return -1;
+        }
       digit2 = in[1];
       if (digit2 > 127 || b64val (digit2) == BAD)
-	return -1;
+        {
+          gnutls_assert();
+	  return -1;
+        }
       digit3 = in[2];
       if (digit3 > 127 || ((digit3 != '=') && (b64val (digit3) == BAD)))
-	return -1;
+        {
+          gnutls_assert();
+	  return -1;
+        }
       digit4 = in[3];
       if (digit4 > 127 || ((digit4 != '=') && (b64val (digit4) == BAD)))
-	return -1;
+	{
+	  gnutls_assert();
+	  return -1;
+        }
       in += 4;
 
       /* digits are already sanity-checked */
@@ -304,7 +322,10 @@ is_armored (int ctb)
   int pkttype = 0;
 
   if (!(ctb & 0x80))
-    return 1;			/* invalid packet: assume it is armored */
+    {
+      gnutls_assert();
+      return 1;			/* invalid packet: assume it is armored */
+    }
   pkttype = ctb & 0x40 ? (ctb & 0x3f) : ((ctb >> 2) & 0xf);
   switch (pkttype)
     {
@@ -348,10 +369,16 @@ armor_encode (void *data, FILE * in, FILE * out)
   const char *lf;
 
   if (!afx)
-    return CDK_Inv_Value;
+    {
+      gnutls_assert();
+      return CDK_Inv_Value;
+    }
   if (afx->idx < 0 || afx->idx > (int) DIM (armor_begin) ||
       afx->idx2 < 0 || afx->idx2 > (int) DIM (armor_end))
-    return CDK_Inv_Value;
+    {
+      gnutls_assert();
+      return CDK_Inv_Value;
+    }
 
   _cdk_log_debug ("armor filter: encode\n");
 
@@ -365,7 +392,10 @@ armor_encode (void *data, FILE * in, FILE * out)
   fprintf (out, "%s", lf);
 
   if (fstat (fileno (in), &statbuf))
-    return CDK_General_Error;
+    {
+      gnutls_assert();
+      return CDK_General_Error;
+    }
 
   while (!feof (in))
     {
@@ -373,7 +403,10 @@ armor_encode (void *data, FILE * in, FILE * out)
       if (!nread)
 	break;
       if (ferror (in))
-	return CDK_File_Error;
+        {
+          gnutls_assert();
+  	  return CDK_File_Error;
+        }
       afx->crc = update_crc (afx->crc, (byte *) raw, nread);
       base64_encode (buf, (byte *) raw, nread, DIM (buf) - 1);
       fprintf (out, "%s%s", buf, lf);
@@ -428,7 +461,10 @@ search_header (const char *buf, const char **array)
   int i;
 
   if (strlen (buf) < 5 || strncmp (buf, "-----", 5))
-    return -1;
+    {
+      gnutls_assert();
+      return -1;
+    }
   for (i = 0; (s = array[i]); i++)
     {
       if (!strncmp (s, buf + 5, strlen (s)))
@@ -458,7 +494,10 @@ armor_decode (void *data, FILE * in, FILE * out)
   cdk_error_t rc = 0;
 
   if (!afx)
-    return CDK_Inv_Value;
+    {
+      gnutls_assert();
+      return CDK_Inv_Value;
+    }
 
   _cdk_log_debug ("armor filter: decode\n");
 
@@ -475,7 +514,10 @@ armor_decode (void *data, FILE * in, FILE * out)
     }
 
   if (feof (in) || !pgp_data)
-    return CDK_Armor_Error;	/* no data found */
+    {
+      gnutls_assert();
+      return CDK_Armor_Error;	/* no data found */
+    }
 
   /* Parse header until the empty line is reached */
   while (!feof (in))
@@ -492,7 +534,10 @@ armor_decode (void *data, FILE * in, FILE * out)
          Headers to be corruption of the ASCII Armor. A colon and a single
          space separate the key and value. */
       if (!strstr (buf, ": "))
-	return CDK_Armor_Error;
+        {
+          gnutls_assert();
+  	  return CDK_Armor_Error;
+        }
       rc = CDK_General_Error;
       for (i = 0; (s = valid_headers[i]); i++)
 	{
@@ -579,12 +624,16 @@ cdk_file_armor (cdk_ctx_t hd, const char *file, const char *output)
 
   rc = cdk_stream_open (file, &inp);
   if (rc)
-    return rc;
+    {
+      gnutls_assert();
+      return rc;
+    }
 
   rc = cdk_stream_new (output, &out);
   if (rc)
     {
       cdk_stream_close (inp);
+      gnutls_assert();
       return rc;
     }
 
@@ -621,16 +670,23 @@ cdk_file_dearmor (const char *file, const char *output)
 
   rc = _cdk_check_args (1, file, output);
   if (rc)
-    return rc;
+    {
+      gnutls_assert();
+      return rc;
+    }
 
   rc = cdk_stream_open (file, &inp);
   if (rc)
-    return rc;
+    {
+      gnutls_assert();
+      return rc;
+    }
 
   rc = cdk_stream_create (output, &out);
   if (rc)
     {
       cdk_stream_close (inp);
+      gnutls_assert();
       return rc;
     }
 
@@ -650,6 +706,7 @@ cdk_file_dearmor (const char *file, const char *output)
 
   cdk_stream_close (inp);
   cdk_stream_close (out);
+  gnutls_assert();
   return rc;
 }
 
@@ -672,6 +729,8 @@ _cdk_filter_armor (void *data, int ctl, FILE * in, FILE * out)
 	  return 0;
 	}
     }
+
+  gnutls_assert();
   return CDK_Inv_Mode;
 }
 
@@ -698,9 +757,15 @@ cdk_armor_encode_buffer (const byte * inbuf, size_t inlen,
   size_t pos, off, len, rest;
 
   if (!inbuf || !nwritten)
-    return CDK_Inv_Value;
+    {
+      gnutls_assert();
+      return CDK_Inv_Value;
+    }
   if (type > CDK_ARMOR_SIGNATURE)
-    return CDK_Inv_Mode;
+    {
+      gnutls_assert();
+      return CDK_Inv_Mode;
+    }
 
   head = armor_begin[type];
   tail = armor_end[type];
@@ -710,7 +775,10 @@ cdk_armor_encode_buffer (const byte * inbuf, size_t inlen,
   pos += (4 * inlen / 3) + 2 * (4 * inlen / 3 / 64);
 
   if (outbuf && outlen < pos)
-    return CDK_Too_Short;
+    {
+      gnutls_assert();
+      return CDK_Too_Short;
+    }
 
   /* Only return the size of the output. */
   if (!outbuf)
