@@ -584,12 +584,28 @@ main (int argc, char **argv)
 
   gcry_control (GCRYCTL_ENABLE_QUICK_RANDOM, 0);
 
+#ifdef gcry_fips_mode_active
+  if (gcry_fips_mode_active())
+    {
+      ret = gnutls_register_md5_handler ();
+      if (ret)
+	fprintf (stderr, "gnutls_register_md5_handler: %s\n",
+		 gnutls_strerror (ret));
+    }
+#endif
+
   if ((ret = gnutls_global_init ()) < 0)
     {
       fprintf (stderr, "global_init: %s\n", gnutls_strerror (ret));
       exit (1);
     }
 
+  if ((ret = gnutls_global_init_extra ()) < 0)
+    {
+      fprintf (stderr, "global_init_extra: %s\n", gnutls_strerror (ret));
+      exit (1);
+    }
+
   gaa_parser (argc, argv);
   if (hostname == NULL)
     {
