@@ -8,12 +8,12 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- *               
+ *
  * GNUTLS is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *                               
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -756,24 +756,34 @@ print_list (int verbose)
 	  printf ("\n");
       }
   }
-}
 
-void
-print_license (void)
-{
-  fputs ("\nCopyright (C) 2004,2005,2006,2007 Free Software Foundation\n"
-	 "This program is free software; you can redistribute it and/or modify \n"
-	 "it under the terms of the GNU General Public License as published by \n"
-	 "the Free Software Foundation; either version 3 of the License, or \n"
-	 "(at your option) any later version. \n" "\n"
-	 "This program is distributed in the hope that it will be useful, \n"
-	 "but WITHOUT ANY WARRANTY; without even the implied warranty of \n"
-	 "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the \n"
-	 "GNU General Public License for more details. \n" "\n"
-	 "You should have received a copy of the GNU General Public License \n"
-	 "along with this program; if not, write to the Free Software \n"
-	 "Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.\n\n",
-	 stdout);
+  {
+    const gnutls_pk_algorithm_t *p = gnutls_pk_list ();
+
+    printf ("Public Key Systems: ");
+    for (; *p; p++)
+      {
+	printf ("%s", gnutls_pk_algorithm_get_name (*p));
+	if (*(p + 1))
+	  printf (", ");
+	else
+	  printf ("\n");
+      }
+  }
+
+  {
+    const gnutls_sign_algorithm_t *p = gnutls_sign_list ();
+
+    printf ("PK-signatures: ");
+    for (; *p; p++)
+      {
+	printf ("%s", gnutls_sign_algorithm_get_name (*p));
+	if (*(p + 1))
+	  printf (", ");
+	else
+	  printf ("\n");
+      }
+  }
 }
 
 static int depr_printed = 0;
