@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004, 2005 Free Software Foundation
+ * Copyright (C) 2004, 2005, 2008 Free Software Foundation
  *
  * Author: Simon Josefsson
  *
@@ -36,6 +36,9 @@ doit (void)
   MD5_CTX c;
   unsigned char md[MD5_DIGEST_LENGTH];
 
+  if (gnutls_global_init () != 0)
+    fail ("gnutls_global_init\n");
+
   if (!gnutls_check_version (LIBGNUTLS_VERSION))
     success ("gnutls_check_version ERROR\n");
 
